<?php

/*
 * This file is part of Resume.PHP.
 *
 * (copyleft) R. Eric Wheeler <sikofitt@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Sikofitt\Form\Type;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormConfigInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Csrf\CsrfToken;
use Symfony\Component\Validator\Constraints\Email;
use Symfony\Component\Validator\Constraints\Length;
use Symfony\Component\Validator\Constraints\NotBlank;

/**
 * Class ContactType
 * @package Sikofitt\Form\Type
 */
class ContactType extends AbstractType
{

  /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {

        $builder
          ->setAction('/api/v1/message')
            ->add('name', TextType::class, [
                'constraints' => [
                    new Length([
                            'min' => 5]
                    ),
                    new NotBlank(),
                ],
                'attr' => [
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Your name',
                ],
                'label' => 'Name',
                'label_attr' => [
                    'class' => 'uk-hidden-small uk-form-label',
                ],
            ])
            ->add('email', EmailType::class, [
                'constraints' => [
                    new NotBlank(),
                    new Email(),
                ],
                'attr' => [
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Email address',
                ],
                'label' => 'Email',
                'label_attr' => [
                    'class' => 'uk-hidden-small uk-form-label',
                ],
            ])
            ->add('message', TextareaType::class, [
                'attr' => [
                    'rows' => 5,
                    'cols' => 40,
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Please leave me a message. I will get back to you as soon as possible.',
                ],
                'constraints' => [
                    new NotBlank(),
                    new Length([
                        'min' => 20,
                    ]),
                ],
                'label_attr' => [
                    'class' => 'uk-hidden-small uk-form-label',
                ],
                'label' => 'If you prefer you can send me a message at eric@ericwheeler.net',
            ])

            ->add('submit', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-large uk-button-primary uk-align-right'
                ],
                'label' => 'Send',

            ])
            ->getForm()
        ;
    }

    /**
     * {@inheritdoc}
     *
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'attr' => [
                'class' => 'uk-form uk-form-horizontal',
                'onsubmit' => 'return false;',
            ],
        ]);
    }
}
